#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.3
visibility:           public
id:                   xmonad-extras-0.17.3-5tAkbkq48mrBPhPAKW0qje
key:                  xmonad-extras-0.17.3-5tAkbkq48mrBPhPAKW0qje
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  a89959c0a44f23f39a635643a48bfaad
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.3-5tAkbkq48mrBPhPAKW0qje
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    alsa-mixer-0.3.0.1-D5NqpzQN3mDH3TSCPqK4Sy base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-534ZPXEG79480bRSb8Ut3R
    hint-0.9.0.8-4KgNRPq37bq502SeqyEIN7
    libmpd-0.10.0.1-Lu5mOpW4roUC6To9qGxbi mtl-2.3.1
    network-3.1.4.0-5QGUGxzwH322yW8TioI43L
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF
    xmonad-0.18.0-9m1pXuMJ86z8GjG4H4cn1h
    xmonad-contrib-0.18.1-DNbYeKoXSoyKrPmL24fghC

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

